@@ -37,10 +37,10 @@ namespace Kwave
 	    Osc();
 
 	    /** Destructor */
-	    virtual ~Osc();
+            virtual ~Osc() Q_DECL_OVERRIDE;
 
 	    /** does the calculation */
-	    void goOn() Q_DECL_OVERRIDE;
+            virtual void goOn() Q_DECL_OVERRIDE;
 
 	signals:
 	    /** emits a block with sine wave data */
